@@ -83,6 +83,7 @@ const bool havegl=false;
 mode_t mask;
   
 string systemDir=ASYMPTOTE_SYSDIR;
+string defaultEPSdriver="eps2write";
 
 #ifndef __MSDOS__
   
@@ -99,7 +100,7 @@ string defaultPDFViewer="cygstart";
 string defaultPDFViewer="acroread";
 #endif  
 string defaultGhostscript="gs";
-string defaultGhostscriptLibrary="/usr/lib/libgs.so";
+string defaultGhostscriptLibrary="";
 string defaultDisplay="display";
 string defaultAnimate="animate";
 void queryRegistry() {}
@@ -185,7 +186,7 @@ string getEntry(const string& key)
 
 void queryRegistry()
 {
-  defaultGhostscriptLibrary=getEntry("GPL Ghostscript/*/GS_DLL");
+  string defaultGhostscriptLibrary=getEntry("GPL Ghostscript/*/GS_DLL");
   if(defaultGhostscriptLibrary.empty())
     defaultGhostscriptLibrary=getEntry("AFPL Ghostscript/*/GS_DLL");
   
@@ -869,7 +870,7 @@ void addOption(option *o) {
 
 void version()
 {
-  cerr << PROGRAM << " version " << VERSION << SVN_REVISION
+  cerr << PROGRAM << " version " << REVISION
        << " [(C) 2004 Andy Hammerlindl, John C. Bowman, Tom Prince]" 
        << endl;
 }
@@ -1068,14 +1069,14 @@ void initSettings() {
 // ALT LEFT: pan
   const char *leftbutton[]={"rotate","zoom","shift","pan",NULL};
   
-// MIDDLE: menu (must be unmodified; ignores Shift, Ctrl, and Alt)
-  const char *middlebutton[]={"menu",NULL};
+// MIDDLE:
+  const char *middlebutton[]={NULL};
   
-// RIGHT: zoom/menu (must be unmodified)
+// RIGHT: zoom
 // SHIFT RIGHT: rotateX
 // CTRL RIGHT: rotateY
 // ALT RIGHT: rotateZ
-  const char *rightbutton[]={"zoom/menu","rotateX","rotateY","rotateZ",NULL};
+  const char *rightbutton[]={"zoom","rotateX","rotateY","rotateZ",NULL};
   
 // WHEEL_UP: zoomin
   const char *wheelup[]={"zoomin",NULL};
@@ -1232,6 +1233,8 @@ void initSettings() {
                               ".."));
   addOption(new boolSetting("multiline", 0,
                             "Input code over multiple lines at the prompt"));
+  addOption(new boolSetting("xasy", 0,
+                            "Special interactive mode for xasy"));
 
   addOption(new boolSetting("wait", 0,
                             "Wait for child processes to finish before exiting"));
@@ -1241,7 +1244,7 @@ void initSettings() {
                             true));
                             
   addOption(new boolSetting("quiet", 'q',
-                            "Suppress welcome message"));
+                            "Suppress welcome text and noninteractive stdout"));
   addOption(new boolSetting("localhistory", 0,
                             "Use a local interactive history file"));
   addOption(new IntSetting("historylines", 0, "n",
@@ -1268,6 +1271,7 @@ void initSettings() {
   addOption(new userSetting("user", 'u', "string",
                             "General purpose user string"));
   
+  addOption(new IntSetting("maxvertices", 0, "n", "Maximum number of vertices to queue", 0));
   addOption(new realSetting("zoomfactor", 0, "factor", "Zoom step factor",
                             1.05));
   addOption(new realSetting("zoomstep", 0, "step", "Mouse motion zoom step",
@@ -1303,6 +1307,7 @@ void initSettings() {
   addOption(new envSetting("psviewer", defaultPSViewer));
   addOption(new envSetting("gs", defaultGhostscript));
   addOption(new envSetting("libgs", defaultGhostscriptLibrary));
+  addOption(new envSetting("epsdriver", defaultEPSdriver));
   addOption(new envSetting("texpath", ""));
   addOption(new envSetting("texcommand", ""));
   addOption(new envSetting("dvips", "dvips"));
@@ -1330,11 +1335,18 @@ void setInteractive()
 {
   if(numArgs() == 0 && !getSetting<bool>("listvariables") && 
      getSetting<string>("command").empty() &&
-     (isatty(STDIN_FILENO) || getSetting<Int>("inpipe") >= 0))
+     (isatty(STDIN_FILENO) || getSetting<Int>("xasy")))
     interact::interactive=true;
   
-  historyname=getSetting<bool>("localhistory") ? 
-    (string(getPath())+dirsep+"."+suffix+"_history") : (initdir+"/history");
+  if(getSetting<bool>("localhistory"))
+    historyname=string(getPath())+dirsep+"."+suffix+"_history";
+  else {
+    if(mkdir(initdir.c_str(),0777) != 0 && errno != EEXIST)
+      cerr << "failed to create directory "+initdir+"." << endl;
+    historyname=initdir+"/history";
+  }
+  if(verbose > 1)
+     cerr << "Using history " << historyname << endl;
 }
 
 bool view()
@@ -1366,7 +1378,11 @@ string lookup(const string& symbol)
 {
   string s;
   mem::vector<string> cmd;
-  cmd.push_back("kpsewhich");
+  string kpsewhich="kpsewhich";
+  string fullname=stripFile(argv0)+kpsewhich;
+  std::ifstream exists(fullname.c_str());
+  if(!exists) fullname=kpsewhich;
+  cmd.push_back(fullname);
   cmd.push_back("--var-value="+symbol);
   iopipestream pipe(cmd);
   pipe >> s;
@@ -1403,9 +1419,10 @@ void initDir() {
   if(mask == 0) mask=0027;
   umask(mask);
 #endif  
-  if(verbose > 1)
-    cerr << "Using configuration directory " << initdir << endl;
-  mkdir(initdir.c_str(),0777);
+  if(access(initdir.c_str(),F_OK) == 0) {
+    if(verbose > 1)
+      cerr << "Using configuration directory " << initdir << endl;
+  }
 }
   
 void setPath() {
@@ -1420,7 +1437,8 @@ void setPath() {
     }
     if(i < asydir.length()) searchPath.push_back(asydir.substr(i));
   }
-  searchPath.push_back(initdir);
+  if(access(initdir.c_str(),F_OK) == 0)
+    searchPath.push_back(initdir);
   string sysdir=getSetting<string>("sysdir");
   if(sysdir != "")
     searchPath.push_back(sysdir);
@@ -1453,6 +1471,11 @@ bool xe(const string& texengine)
   return texengine == "xelatex";
 }
 
+bool lua(const string& texengine)
+{
+  return texengine == "luatex" || texengine == "lualatex";
+}
+
 bool context(const string& texengine)
 {
   return texengine == "context";
@@ -1461,7 +1484,7 @@ bool context(const string& texengine)
 bool pdf(const string& texengine)
 {
   return texengine == "pdflatex" || texengine == "pdftex" || xe(texengine) ||
-    texengine == "luatex" || texengine == "lualatex" || context(texengine);
+    lua(texengine) || context(texengine);
 }
 
 bool latex(const string& texengine)
@@ -1567,23 +1590,23 @@ string texprogram()
 Int getScroll() 
 {
   Int scroll=settings::getSetting<Int>("scroll");
-#ifdef HAVE_LIBCURSES  
   if(scroll < 0) {
+#ifdef HAVE_LIBCURSES  
     static char *terminal=NULL;
     if(!terminal)
       terminal=getenv("TERM");
     if(terminal) {
-      int error;
-      error=setupterm(terminal,1,&error);
 #ifndef __MSDOS__      
+      int error=setupterm(terminal,1,&error);
       if(error == 0) scroll=lines > 2 ? lines-1 : 1;
       else
 #endif
         scroll=0;
     } else scroll=0;
-
-  }
+#else
+    scroll=0;
 #endif
+  }
   return scroll;
 }
 
